DefaultLoopDetector class

Implemented types

Constructors

DefaultLoopDetector({required AgentState state, LLMClient? client, ModelConfig? modelConfig, int toolLoopThreshold = 5, int llmCheckAfterTurns = 30, int llmCheckHistorySize = 20, int llmCheckInterval = 10})

Properties

client LLMClient?
final
hashCode int
The hash code for this object.
no setterinherited
llmCheckAfterTurns int
final
llmCheckHistorySize int
final
llmCheckInterval int
final
modelConfig ModelConfig?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AgentState
final
toolLoopThreshold int
final

Methods

detect(ModelMessage chunkMessage) Future<LoopDetectorResult>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited