Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(List<LLMMessage> messages, {List<Tool>? tools, ToolChoice? toolChoice, required ModelConfig modelConfig, bool? jsonOutput, CancelToken? cancelToken})
→ Future<ModelMessage>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
stream(List<LLMMessage> messages, {List<Tool>? tools, ToolChoice? toolChoice, required ModelConfig modelConfig, bool? jsonOutput, CancelToken? cancelToken})
→ Future<Stream<StreamingMessage>>
-
-
toString()
→ String
-
A string representation of this object.
inherited