Tool class

Defines a tool that can be executed by an agent.

A tool consists of a name, description, and a JSON Schema for its parameters. It also contains an executable function that is called when the agent decides to use this tool.

Constructors

Tool({required String name, required String description, required Map<String, dynamic> parameters, Function? executable, List<String> namedParameters = const [], ToolParameterMode parameterMode = ToolParameterMode.function})

Properties

description String
final
executable Function?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
namedParameters List<String>
final
parameterMode ToolParameterMode
final
parameters Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited