ToolChoice class

Constructors

ToolChoice({required ToolChoiceMode mode, List<String>? allowedFunctionNames})
ToolChoice.fromJson(Map<String, dynamic> json)
factory

Properties

allowedFunctionNames List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
mode ToolChoiceMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited