ClassificationMetrics class

Precision/Recall/F1 for binary classification tasks (e.g. Memory Agent).

Constructors

ClassificationMetrics({required int truePositives, required int falsePositives, required int trueNegatives, required int falseNegatives})
const

Properties

accuracy double
no setter
f1 double
no setter
falseNegatives int
final
falsePositives int
final
hashCode int
The hash code for this object.
no setterinherited
precision double
no setter
recall double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trueNegatives int
final
truePositives int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited