controller property
Controller pre-attached with trace exporters and listeners. The harness should reuse this controller, not create its own.
Implementation
final AgentController controller;
Controller pre-attached with trace exporters and listeners. The harness should reuse this controller, not create its own.
final AgentController controller;