recordingStore property
Optional. If set, the runner exposes the store to the harness via the EvalContext (the harness chooses to wrap its LLMClient or not).
Implementation
final RecordingStore? recordingStore;
Optional. If set, the runner exposes the store to the harness via the EvalContext (the harness chooses to wrap its LLMClient or not).
final RecordingStore? recordingStore;