GraduationCandidate class

当一个 task 在最近 N 次 run 都达到成熟通过率,建议毕业到 regression suite。

Constructors

GraduationCandidate({required String taskId, required double recentMeanPassRate, required int consecutiveMatureRuns, required List<String> contributingRuns})
const

Properties

consecutiveMatureRuns → int
final
contributingRuns → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
recentMeanPassRate → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited