queue property
HumanReviewQueue
get
queue
Where to enqueue trials and where to read back human verdicts.
Implementation
HumanReviewQueue get queue;
Where to enqueue trials and where to read back human verdicts.
HumanReviewQueue get queue;