rubric property
String?
get
rubric
Optional rubric prompt shown to human reviewers in the UI.
Implementation
String? get rubric => null;
Optional rubric prompt shown to human reviewers in the UI.
String? get rubric => null;