get method
Returns the recorded response for hash, or null if no recording.
Implementation
@override
Future<ModelMessage?> get(String hash) async => _store[hash];
Returns the recorded response for hash, or null if no recording.
@override
Future<ModelMessage?> get(String hash) async => _store[hash];