RateLimitGate class abstract

Throttles outgoing LLM calls. Independent from runner concurrency.

acquire suspends the caller until the call is allowed. Implementations must be safe to call concurrently from many trials.

Implementers

Constructors

RateLimitGate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquire({int estimatedTokens = 0}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited