RecordingNotFoundException class

Thrown when a ReplayLLMClient cannot find a recorded response and has no fallback configured (or strictReplay is true).

Implemented types

Constructors

RecordingNotFoundException(String hash, {String? requestSummary})

Properties

hash String
final
hashCode int
The hash code for this object.
no setterinherited
requestSummary String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited