get abstract method
Returns the recorded response for hash, or null if no recording.
Implementation
Future<ModelMessage?> get(String hash);
Returns the recorded response for hash, or null if no recording.
Future<ModelMessage?> get(String hash);