RpmRateLimitGate class
Permits up to N requests per minute (token bucket, refill at +N/60s).
- Implemented types
Constructors
- RpmRateLimitGate({required int requestsPerMinute})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestsPerMinute → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acquire(
{int estimatedTokens = 0}) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited