RunIndexEntry class
索引文件中一行的轻量元数据。
Constructors
- RunIndexEntry({required String runName, required String suiteName, required SuiteKind suiteKind, required DateTime startedAt, required DateTime endedAt, required double taskPassRate, required double trialPassRate, required int numTrials})
-
const
-
RunIndexEntry.fromJson(Map<
String, dynamic> json) -
factory
Properties
- endedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- numTrials → int
-
final
- runName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → DateTime
-
final
- suiteKind → SuiteKind
-
final
- suiteName → String
-
final
- taskPassRate → double
-
final
- trialPassRate → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited