SuiteHealthReport class

跨多次 run 的 suite 健康分析。

用法:

final analyzer = SuiteHealthAnalyzer(reportStore);
final report = await analyzer.analyze(
  suiteName: 'card_agent_capability',
  recentRunCount: 10,
);
for (final c in report.graduationCandidates) {
  print('graduate ${c.taskId}: ${c.recentMeanPassRate}');
}

Constructors

SuiteHealthReport({required String suiteName, required SuiteKind suiteKind, required int analyzedRunCount, required SaturationThresholds thresholds, required List<GraduationCandidate> graduationCandidates, required List<BrokenTaskCandidate> brokenTaskCandidates, required double currentSaturationRatio, required bool currentlySaturated, required Map<String, int> difficultyHistogram})
const

Properties

analyzedRunCount int
final
brokenTaskCandidates List<BrokenTaskCandidate>
跨多次 run 都几乎全失败的任务(任务/grader 可能有 bug)。
final
currentlySaturated bool
是否当前已饱和。
final
currentSaturationRatio double
当前最近一次 run 的饱和率。
final
difficultyHistogram Map<String, int>
任务难度分布柱状图。key: 0.0-0.2 / 0.2-0.4 / ... / 0.8-1.0, value: 落入此通过率区间的任务数(基于跨 run 平均通过率)。
final
graduationCandidates List<GraduationCandidate>
在最近 N 次 run 都达到 matureTaskPassRate 的任务。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suiteKind SuiteKind
final
suiteName String
final
thresholds SaturationThresholds
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited