result property
Strongly-typed execution result. May be null when the tool errored before producing one; details should still appear in errorMessage in that case.
Implementation
final FunctionExecutionResult? result;
Strongly-typed execution result. May be null when the tool errored before producing one; details should still appear in errorMessage in that case.
final FunctionExecutionResult? result;