TranscriptEvent class

Lightweight log of additional events that don't fit neatly into messages or tool calls (e.g. retries, plan changes, exceptions).

Constructors

TranscriptEvent({required DateTime at, required String kind, required String message, Map<String, dynamic> details = const {}})
TranscriptEvent.fromJson(Map<String, dynamic> json)
factory

Properties

at DateTime
final
details Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
kind String
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited