Trial class

Metadata about one attempt at a task.

Constructors

Trial({required String runName, required String suiteName, required String taskId, required int trialIndex, required DateTime startedAt, required DateTime endedAt, required TrialStatus status, String? failureReason})
Trial.fromJson(Map<String, dynamic> json)
factory

Properties

cacheSalt String
Stable salt for record/replay caching, scoped per task+trial but independent of run name so that recordings made in run A can be replayed by run B. Format: taskId#trialIndex.
no setter
duration Duration
no setter
endedAt DateTime
final
failureReason String?
Reason set when status is TrialStatus.errored or TrialStatus.timedOut.
final
hashCode int
The hash code for this object.
no setterinherited
id TrialId
no setter
runName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
final
status TrialStatus
final
suiteName String
final
taskId String
final
trialIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited