TrialDisagreement class

Constructors

TrialDisagreement({required TrialId trialId, required double humanScore, required double judgeScore, required double absoluteDelta, String? humanRationale, String? judgeRationale})
const

Properties

absoluteDelta double
final
hashCode int
The hash code for this object.
no setterinherited
humanRationale String?
final
humanScore double
final
judgeRationale String?
final
judgeScore double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trialId TrialId
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited