WorkspaceDiff class

Captures filesystem-level changes between fixture setup and trial end.

Constructors

WorkspaceDiff({List<String> created = const [], List<String> modified = const [], List<String> deleted = const [], Map<String, String> contentSnippets = const {}})
const
WorkspaceDiff.fromJson(Map<String, dynamic> json)
factory

Properties

contentSnippets Map<String, String>
Optional content snippets for created/modified files. Keys are paths. Values are utf-8 text content (trimmed if > 4 KiB).
final
created List<String>
Absolute paths (relative to workspace root) created during the trial.
final
deleted List<String>
Paths deleted.
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
modified List<String>
Paths modified.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited