BeforeRunHookContext class
- Inheritance
-
- Object
- AgentHookContext
- BeforeRunHookContext
Constructors
-
BeforeRunHookContext(StatefulAgent agent, {required List<
LLMMessage> input, required bool stream, CancelToken? cancelToken}) -
const
Properties
- agent → StatefulAgent
-
finalinherited
- cancelToken → CancelToken?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ List<
LLMMessage> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → AgentState
-
no setterinherited
- stream → bool
-
final
Methods
-
copyWith(
{List< LLMMessage> ? input}) → BeforeRunHookContext -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited