FunctionExecutionResult class
Constructors
-
FunctionExecutionResult({required String id, required String name, required bool isError, required String arguments, required List<
UserContentPart> content, Map<String, dynamic> ? metadata, int? timestamp}) -
FunctionExecutionResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- arguments → String
-
final
-
content
→ List<
UserContentPart> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isError → bool
-
final
-
metadata
→ Map<
String, dynamic> ? -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited