ModelCallHookContext class
- Inheritance
-
- Object
- AgentHookContext
- ModelCallHookContext
Constructors
- ModelCallHookContext(StatefulAgent agent, {required ModelCallRequest request, required int turnIndex, CancelToken? cancelToken})
-
const
Properties
- agent → StatefulAgent
-
finalinherited
- cancelToken → CancelToken?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- request → ModelCallRequest
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → AgentState
-
no setterinherited
- turnIndex → int
-
final
Methods
-
copyWith(
{ModelCallRequest? request}) → ModelCallHookContext -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited