AgentHarnessFactory class abstract
Anthropic: an agent harness is the system that lets a model act as an agent. The framework does not assume any specific implementation — applications provide their own factory.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
{required EvalTask task, required Trial trial, required EvalContext context}) → Future< AgentHarnessSession> - Build a session for one trial. Implementations are responsible for:
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited