run abstract method
Run the agent for this trial and produce both a transcript and an outcome. Sessions may return an empty transcript when using the framework recorder; the runner will replace it with the recorded snapshot.
Implementation
Future<({Transcript transcript, Outcome outcome})> run();