CalibrationConfig class
默认配置:超过 0.15 的差距视为"不同意",并报告 top 20 个最严重的偏差。
Constructors
- CalibrationConfig({double agreementTolerance = 0.15, int topDisagreements = 20})
-
const
Properties
- agreementTolerance → double
-
|humanScore - judgeScore| 在此阈值内视为"同意"。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topDisagreements → int
-
报告中显示前 N 个偏差最大的 trial。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited