EvalRunConfig class
Parsed L2 (runner-level) configuration. Sources: CLI args, env vars.
Applications instantiate one in main() and pass fields to the runner.
Constructors
- EvalRunConfig({required String runName, int concurrency = 8, int? trialsOverride, EvalRunMode mode = EvalRunMode.replay, TaskFilter filter = const TaskFilter(), int? rpm, int? tpm, String? recordingDir, bool langfuseEnabled = true, String? langfuseHost})
-
const
Properties
- concurrency → int
-
final
- filter → TaskFilter
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- langfuseEnabled → bool
-
final
- langfuseHost → String?
-
final
- mode → EvalRunMode
-
final
- recordingDir → String?
-
final
- rpm → int?
-
final
- runName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tpm → int?
-
final
- trialsOverride → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited