LangfuseEvent class
Langfuse /api/public/ingestion 上的 event 包装格式。
一条 event 长这样:
{
"id": "<uuid>",
"type": "trace-create" | "generation-create" | ... ,
"timestamp": "2026-05-22T...Z",
"body": { ... }
}
Body schema 参见 langfuse 仓库 packages/shared/src/server/ingestion/types.ts
的 TraceBody / CreateGenerationBody / CreateSpanBody / ScoreBody。
Constructors
Properties
-
body
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Event 自身的 UUID(不是 traceId)。Langfuse 用它做 dedup。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- type → String
-
trace-create/generation-create/generation-update/span-create/span-update/score-create等。final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited