ReportStore class abstract
持久化历史 run report。append-only。
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listRecent(
{required String suiteName, int limit = 10}) → Future< List< RunIndexEntry> > - 列出某 suite 最近 N 次的索引条目(轻量),按时间倒序。
-
listRunNames(
{String? suiteFilter, int? limit}) → Future< List< String> > -
load(
String runName) → Future< PersistedRunReport?> -
loadRecent(
{required String suiteName, int limit = 10}) → Future< List< PersistedRunReport> > - 加载某 suite 最近 N 次完整快照,按时间倒序。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
EvalRunReport report) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited