SuiteSnapshot class
Suite 元数据的不可执行快照。只保留分析需要的字段。
Constructors
-
SuiteSnapshot({required String name, required SuiteKind kind, required List<
String> taskIds, required double taskPassThreshold, required bool requireReferenceSolution}) -
const
- SuiteSnapshot.from(EvalSuite suite)
-
factory
-
SuiteSnapshot.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → SuiteKind
-
final
- name → String
-
final
- requireReferenceSolution → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
taskIds
→ List<
String> -
final
- taskPassThreshold → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited