TaskTransition class
Constructors
- TaskTransition({required String taskId, required double currentPassRate, required double baselinePassRate, required TaskTransitionKind kind})
-
const
Properties
- baselinePassRate → double
-
final
- currentPassRate → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- improved → bool
-
no setter
- kind → TaskTransitionKind
-
final
- regressed → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId → String
-
final
- unchanged → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited