TranscriptEvent class
Lightweight log of additional events that don't fit neatly into messages or tool calls (e.g. retries, plan changes, exceptions).
Constructors
-
TranscriptEvent({required DateTime at, required String kind, required String message, Map<
String, dynamic> details = const {}}) -
TranscriptEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited