TranscriptMetrics class
Quantitative metrics about a trial.
Constructors
- TranscriptMetrics({required int nTurns, required int nToolCalls, required int nTotalTokens, Duration? timeToFirstToken, Duration? timeToLastToken, double? outputTokensPerSec})
-
const
-
TranscriptMetrics.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nToolCalls → int
-
final
- nTotalTokens → int
-
final
- nTurns → int
-
final
- outputTokensPerSec → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeToFirstToken → Duration?
-
final
- timeToLastToken → Duration?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited