TrialResult class

All artifacts produced by one trial.

Constructors

TrialResult({required Trial trial, required Transcript transcript, required Outcome outcome, required List<Score> scores})
const

Properties

allGradersPassed bool
True if every score (excluding null-valued ones) reports passed=true. Null-valued scores (e.g. judge returned Unknown) are ignored.
no setter
hashCode int
The hash code for this object.
no setterinherited
meanScoreValue double?
Mean of non-null score values. Returns null if all scores are null.
no setter
outcome Outcome
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scores List<Score>
final
transcript Transcript
final
trial Trial
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited